Projections
===========

.. toctree::
   :maxdepth: 1

   Pathway Projections <PathwayProjection>
   Modulatory Projections <ModulatoryProjection>

.. automodule:: psyneulink.core.components.projections.projection
   :members:
   :exclude-members: _is_projection_spec, random, Parameters
